@@ -55,5 +55,9 @@ class SKOSKnowledgeParser(KnowledgeParserBase):
         bar.finish()
 
     @classmethod
-    def get_schema(cls) -> Type[BaseModel]:
-        return SKOSOptions
\ No newline at end of file
+    def get_schema(cls) -> KnowledgeParserOptions:
+        return SKOSOptions
+
+    @classmethod
+    def get_model(cls) -> Type[BaseModel]:
+        return SKOSOptionsModel
